.. _run:

run
---

.. automodule:: pvfactors.run
   :no-members:
   :no-inherited-members:
   :noindex:

.. autosummary::
   :toctree: generated/
   :nosignatures:

   ~pvfactors.run.run_timeseries_engine
   ~pvfactors.run.run_parallel_engine
